@@ -303,11 +303,7 @@ def generate_output(response: Response, output_cls: Type[T_], root_field: str =
     except:
         result = {}
     if not isinstance(result, dict):
-        if not root_field:
-            raise AttributeError('Unable to assign ')
-        result = {
-            str(root_field): result
-        }
+        result = {str(root_field): result} if root_field else {}
     elif root_field:
         result = {
             str(root_field): result,
@@ -386,5 +382,5 @@ class WebSdkOutputModel(RootOutputModel):
 class InvalidResponseError(Exception):
     def __init__(self, msg: str, response: Response):
         self.response = response
-        super().__init__(msg)
+        super().__init__(msg, response)
 # endregion Response Definitions
