@@ -3,7 +3,7 @@ from pytpp.attributes.credential_driver_base import CredentialDriverBaseAttribut
 
 
 class AdaptableCredentialConnectorAttributes(CredentialDriverBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Adaptable Credential Connector"
     credential = Attribute('Credential', min_version='21.1')
     powershell_script = Attribute('PowerShell Script', min_version='21.1')
     powershell_script_hash_vault_id = Attribute('PowerShell Script Hash Vault Id', min_version='21.1')
