@@ -3,7 +3,7 @@ from pytpp.attributes.driver_base import DriverBaseAttributes
 
 
 class CertificateAuthorityBaseAttributes(DriverBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Certificate Authority Base"
     additional_field = Attribute('Additional Field')
     concurrent_connection_limit = Attribute('Concurrent Connection Limit')
     credential = Attribute('Credential')
