@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class CodeSigningProjectAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Code Signing Project"
     approval_submission_date = Attribute('Approval Submission Date', min_version='21.2')
     auditor = Attribute('Auditor', min_version='19.2')
     certificate_issue_flow_dn = Attribute('Certificate Issue Flow DN', min_version='19.2')
