@@ -3,5 +3,5 @@ from pytpp.attributes.top import TopAttributes
 
 
 class ExclusionAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Exclusion"
     rule = Attribute('Rule')
