@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class GlobalSignMSSLCAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "GlobalSign MSSL CA"
     domain_id = Attribute('Domain ID')
     profile_id = Attribute('Profile ID')
     san_type = Attribute('SAN Type')
