@@ -3,7 +3,7 @@ from pytpp.attributes.certificate_authority_base import CertificateAuthorityBase
 
 
 class HTTPCABaseAttributes(CertificateAuthorityBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "HTTP CA Base"
     bypass_proxy_on_local = Attribute('Bypass Proxy on Local')
     proxy_credential = Attribute('Proxy Credential')
     proxy_host = Attribute('Proxy Host')
