@@ -3,7 +3,7 @@ from pytpp.attributes.service_module import ServiceModuleAttributes
 
 
 class KmipServiceModuleAttributes(ServiceModuleAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Kmip Service Module"
     agent_module_handlers = Attribute('Agent Module Handlers')
     agent_upgrade_rule = Attribute('Agent Upgrade Rule')
     credential = Attribute('Credential')
