@@ -3,7 +3,7 @@ from pytpp.attributes.http_ca_base import HTTPCABaseAttributes
 
 
 class OpenTrustPKICAAttributes(HTTPCABaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "OpenTrust PKI CA"
     connector_type = Attribute('Connector Type')
     fields = Attribute('Fields')
     retrieval_period = Attribute('Retrieval Period')
