@@ -3,7 +3,7 @@ from pytpp.attributes.application_base import ApplicationBaseAttributes
 
 
 class PKCS12Attributes(ApplicationBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "PKCS#12"
     bundle_certificate = Attribute('Bundle Certificate')
     certificate_chain_file = Attribute('Certificate Chain File')
     certificate_file = Attribute('Certificate File')
