@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class ProxyAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Proxy"
     bypass_proxy_on_local = Attribute('Bypass Proxy on Local')
     credential = Attribute('Credential')
     proxy_credential = Attribute('Proxy Credential')
