@@ -4,7 +4,7 @@ from pytpp.attributes.report_filter_base import ReportFilterBaseAttributes
 
 
 class ReportCertificateInventoryAttributes(ReportBaseAttributes, ReportFilterBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Report:CertificateInventory"
     grouping = Attribute('Grouping')
     options = Attribute('Options')
     policydn = Attribute('PolicyDN')
