@@ -3,5 +3,5 @@ from pytpp.attributes.report_base import ReportBaseAttributes
 
 
 class ReportSSHUserKeyAttributes(ReportBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Report:SSH User Key"
     options = Attribute('Options')
