@@ -3,7 +3,7 @@ from pytpp.attributes.top import TopAttributes
 
 
 class TreeRootAttributes(TopAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Tree Root"
     company_name = Attribute('Company Name', min_version='17.3')
     migration_task = Attribute('Migration Task')
     pendo_eula_version = Attribute('Pendo EULA Version', min_version='19.2')
