@@ -3,5 +3,5 @@ from pytpp.attributes.credential_base import CredentialBaseAttributes
 
 
 class UsernamePasswordCredentialAttributes(CredentialBaseAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Username Password Credential"
     username = Attribute('Username')
