@@ -2,7 +2,7 @@ from pytpp.attributes._helper import IterableMeta, Attribute
 
 
 class ValidationBaseAttributes(metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "Validation Base"
     file_validation_error = Attribute('File Validation Error', min_version='15.3')
     file_validation_result = Attribute('File Validation Result', min_version='15.3')
     last_validation = Attribute('Last Validation')
