@@ -3,4 +3,4 @@ from pytpp.attributes.x509_certificate import X509CertificateAttributes
 
 
 class X509TimeStampingCertificateAttributes(X509CertificateAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "X509 Time Stamping Certificate"
