@@ -4,7 +4,7 @@ from pytpp.attributes.proxy import ProxyAttributes
 
 
 class zOSCAAttributes(HTTPCABaseAttributes, ProxyAttributes, metaclass=IterableMeta):
-    __config_class__ = "{key}"
+    __config_class__ = "zOS CA"
     client_port = Attribute('Client Port')
     client_secure = Attribute('Client Secure')
     domain = Attribute('Domain')
