@@ -1,10 +1,11 @@
 from pytpp.features.bases.feature_base import FeatureBase, feature
 from pytpp.features.definitions.exceptions import InvalidResultCode
-from pytpp.properties.config import ClientGroupsAttributeValues
+from pytpp.api.websdk.enums.config import ClientGroupsAttributeValues
 from pytpp.attributes.client_group import ClientGroupAttributes
 from typing import Union, TYPE_CHECKING
+
 if TYPE_CHECKING:
-    from pytpp.tools.vtypes import Config
+    from pytpp.api.websdk.models import config
 
 
 class _ClientGroupBase(FeatureBase):
@@ -14,7 +15,7 @@ class _ClientGroupBase(FeatureBase):
         self._group_base_dn = r'\VED\Clients\Groups'
         self._work_base_dn = r'\VED\Clients\Work'
 
-    def assign_work(self, group: 'Union[Config.Object, str]', work: 'Union[Config.Object, str]'):
+    def assign_work(self, group: 'Union[config.Object, str]', work: 'Union[config.Object, str]'):
         """
         Assigns work to the client group
 
@@ -37,7 +38,7 @@ class _ClientGroupBase(FeatureBase):
                 code_description=response.result.credential_result
             )
 
-    def delete(self, group: 'Union[Config.Object, str]'):
+    def delete(self, group: 'Union[config.Object, str]'):
         """
         Deletes a client group
 
@@ -77,7 +78,7 @@ class _ClientGroupBase(FeatureBase):
             )
         return response.objects
 
-    def remove_work(self, group: 'Union[Config.Object, str]', work: 'Union[Config.Object, str]'):
+    def remove_work(self, group: 'Union[config.Object, str]', work: 'Union[config.Object, str]'):
         """
         Removes work from a client group
 
@@ -116,13 +117,8 @@ class Agentless(_ClientGroupBase):
             ClientGroupAttributes.rule      : ClientGroupsAttributeValues.DefaultRules.agentless
         }
 
-        return self._config_create(
-            name=name,
-            parent_folder_dn=self._group_base_dn,
-            config_class=ClientGroupAttributes.__config_class__,
-            attributes=attributes,
-            get_if_already_exists=get_if_already_exists
-        )
+        return self._config_create(name=name, parent_folder_dn=self._group_base_dn, config_class=ClientGroupAttributes.__config_class__, attributes=attributes,
+                                   get_if_already_exists=get_if_already_exists)
 
 
 @feature('EST Certificate Enrollment Group')
@@ -142,13 +138,8 @@ class EstCertificateEnrollment(_ClientGroupBase):
             ClientGroupAttributes.rule      : ClientGroupsAttributeValues.DefaultRules.est
         }
 
-        return self._config_create(
-            name=name,
-            parent_folder_dn=self._group_base_dn,
-            config_class=ClientGroupAttributes.__config_class__,
-            attributes=attributes,
-            get_if_already_exists=get_if_already_exists
-        )
+        return self._config_create(name=name, parent_folder_dn=self._group_base_dn, config_class=ClientGroupAttributes.__config_class__, attributes=attributes,
+                                   get_if_already_exists=get_if_already_exists)
 
 
 @feature('Venafi Agent Group')
@@ -168,11 +159,5 @@ class VenafiAgent(_ClientGroupBase):
             ClientGroupAttributes.rule      : ClientGroupsAttributeValues.DefaultRules.venafi_agent
         }
 
-        return self._config_create(
-            name=name,
-            parent_folder_dn=self._group_base_dn,
-            config_class=ClientGroupAttributes.__config_class__,
-            attributes=attributes,
-            get_if_already_exists=get_if_already_exists
-        )
-
+        return self._config_create(name=name, parent_folder_dn=self._group_base_dn, config_class=ClientGroupAttributes.__config_class__, attributes=attributes,
+                                   get_if_already_exists=get_if_already_exists)
